@@ -9,7 +9,7 @@ use vars qw($VERSION);
 
 # Initialize our version
 # $Revision: 1181 $
-$VERSION = '1.44';
+$VERSION = '1.46';
 
 # Import what we need from the POE namespace
 use POE;
@@ -721,6 +721,10 @@ sub Got_Input {
 				$path = '/';
 			}
 		}
+		else {
+			# We're in PROXYMODE set the path to the full URI
+			$path = $request->uri->as_string();
+		}
 
 		# Get the response
         $response = POE::Component::Server::SimpleHTTP::Response->new(
